@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: configuration.cpp,v 1.29 2002/06/23 19:13:18 xavier Exp $
+// $Id: configuration.cpp,v 1.29.2.1 2003/02/12 00:51:33 staikos Exp $
 
 #include <qlabel.h>
 #include <qlayout.h>
@@ -37,6 +37,7 @@
 #include <kstandarddirs.h>
 #include <kurlrequester.h>
 #include <kparts/browserextension.h>
+#include <kiconloader.h>
 
 #include "configparser.h"
 #include "configlist.h"
@@ -232,12 +233,15 @@ void Configuration::slotDelayedHelp()
 				QFile f(locate("data", "kcmlinuz/data/intro.html"));
 				if (f.open(IO_ReadOnly))
 				{
+					KIconLoader *kil = KGlobal::instance()->iconLoader();
 					QTextStream str(&f);
 					m_intro = str.read()
 						.arg(i18n("Linux Kernel Configurator"))
 						.arg(i18n("Option is disabled"))
 						.arg(i18n("Option is enabled"))
-						.arg(i18n("Compiled as a module"));
+						.arg(i18n("Compiled as a module"))
+						.arg(kil->iconPath("idea", KIcon::Small))
+						.arg(i18n("Information"));
 				}
 			}
 			help = m_intro;
