@@ -20,6 +20,8 @@
 #include <vector>
 #include <string>
 
+#include <qstring.h> // Whatever
+
 class CTCron;
 
 /**
@@ -69,6 +71,17 @@ public:
   */
   bool root() const;
 
+/**
+  * Indicates an error has occured.
+  */
+  bool isError() { return !error.isEmpty(); }
+
+/**
+  * Error message
+  */
+  QString errorMessage() { QString r = error; error = QString::null; return r; }  
+
+
 /**
   * User(s). 
   *
@@ -78,7 +91,7 @@ public:
   * If the user is a non-root user, there will be only one member in the
   * cron vector.
   */
-  vector<CTCron*> cron;
+  std::vector<CTCron*> cron;
 
 private:
 
@@ -95,10 +108,11 @@ private:
 /**
   * Factory create a cron table.  Appends to the end of cron.
   */
-  CTCron* createCTCron(bool _syscron = false, string _login = "");
+  CTCron* createCTCron(bool _syscron = false, std::string _login = "");
 
+  QString error;
 };
 
-typedef vector<CTCron*>::iterator CTCronIterator;
+typedef std::vector<CTCron*>::iterator CTCronIterator;
 
 #endif // CTHOST_H
