@@ -1,5 +1,6 @@
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -24,7 +25,9 @@
 #include <qlayout.h>
 #include <qpushbutton.h>
 
-#include <kapp.h>
+#include <kapplication.h>
+#include <klocale.h>
+#include <kmessagebox.h>
 
 #include "LoggerWidget.h"
 #include "Options.h"
@@ -34,8 +37,6 @@
 #include "TapeManager.h"
 #include "TarParser.h"
 #include "Util.h"
-#include <klocale.h>
-#include <qmessagebox.h>
 
 #include "IndexDlg.moc"
 
@@ -79,10 +80,10 @@ IndexDlg::IndexDlg( Tape* tape, QWidget* parent, const char* name )
     _archives = new QLabel( i18n( "0" ), f2 );
     _archives->setFixedHeight( _archives->sizeHint().height() );
 
-    QLabel* lbl3 = new QLabel( i18n( "Kbytes read:" ), f1 );
+    QLabel* lbl3 = new QLabel( i18n( "KB read:" ), f1 );
     lbl3->setFixedSize( labelWidth, lbl3->sizeHint().height() );
 
-    _kbytesRead = new QLabel( i18n( "0k" ), f1 );
+    _kbytesRead = new QLabel( i18n( "0KB" ), f1 );
     _kbytesRead->setFixedHeight( _kbytesRead->sizeHint().height() );
 
     QLabel* lbl4 = new QLabel( i18n( "Files:" ), f2 );
@@ -94,7 +95,7 @@ IndexDlg::IndexDlg( Tape* tape, QWidget* parent, const char* name )
     QLabel* lbl5 = new QLabel( i18n( "Transfer rate:" ), f1 );
     lbl5->setFixedSize( labelWidth, lbl5->sizeHint().height() );
 
-    _transferRate = new QLabel( i18n( "0k/min" ), f1 );
+    _transferRate = new QLabel( i18n( "0KB/min" ), f1 );
     _transferRate->setFixedHeight( _transferRate->sizeHint().height() );
 
     QLabel* lbl6 = new QLabel( i18n( "Total files:" ), f2 );
@@ -194,6 +195,10 @@ void IndexDlg::slotEntry( const QString & name, int size, int mtime, int record
     _fileMTime       = mtime;
     _fileStartRecord = record;
 
+    /* 2002-01-28 LEW */
+    // printf("IndexDlg::slotEntry called with \"%s\", %d bytes\n", name.latin1(), size);
+    /* 2002-01-28 LEW */
+
     QString tmp;
     tmp.setNum( ++_numFiles );
     _files->setText( tmp );
@@ -226,7 +231,7 @@ void IndexDlg::timerEvent( QTimerEvent* )
     // Rewind tape.
     _log->append( i18n( "Rewinding tape." ) );
     if ( !TapeDrive::instance()->rewind() ) {
-        QMessageBox::warning( this, i18n( "KDat: Cannot Rewind Tape" ), i18n( "Cannot rewind tape.  Indexing aborted." ), i18n("OK"));
+        KMessageBox::error( this, i18n( "Cannot rewind tape. Indexing aborted." ));
         _ok->setEnabled( TRUE );
         _save->setEnabled( TRUE );
         _abort->setEnabled( FALSE );
@@ -236,9 +241,7 @@ void IndexDlg::timerEvent( QTimerEvent* )
 
     // Skip tape ID.
     if ( !TapeDrive::instance()->nextFile( 1 ) ) {
-        QMessageBox::warning( this, i18n( "KDat: Error" ), 
-			      i18n( "Failed to skip tape ID." ), 
-			      i18n("OK"));
+        KMessageBox::error( this, i18n( "Failed to skip tape ID. Indexing aborted." ));
         _ok->setEnabled( TRUE );
         _save->setEnabled( TRUE );
         _abort->setEnabled( FALSE );
