@@ -234,6 +234,15 @@ KDat::~KDat()
     if ( Options::instance()->getLockOnMount() ) {
         TapeDrive::instance()->unlock();
     }
+    delete _tapeDriveMenu;
+    delete _archiveMenu;
+    delete _mountedArchiveMenu;
+    delete _mountedTapeFileMenu;
+    delete _localFileMenu;
+    delete _tapeMenu;
+    delete _backupProfileRootMenu;
+    delete _backupProfileMenu;
+
 }
 
 void KDat::popupTapeDriveMenu( const QPoint& p )
@@ -371,7 +380,7 @@ void KDat::localSelected( int index )
 
     /* 2002-01-30 LEW: RG and I don't like the behavior in which
        the subtree expands or contracts when a directory is selected
-       or unselected. 
+       or unselected.
        so make the tree look the same when we are done....
        The goal is to redraw the icon to the left of the item.
        There's gotta be a better way to do this. */
@@ -483,7 +492,7 @@ void KDat::fileBackup()
                         "Back up anyway?" )
               .arg(KGlobal::locale()->formatNumber(size, 0))
               .arg(KGlobal::locale()->formatNumber(TapeManager::instance()->getMountedTape()->getSize() - tapeSize, 0 ));
-            int result = KMessageBox::warningContinueCancel( this, 
+            int result = KMessageBox::warningContinueCancel( this,
                                msg, i18n("Backup"), i18n("Backup") );
             if ( result != KMessageBox::Continue) {
                 status( i18n( "Backup canceled." ) );
@@ -495,8 +504,8 @@ void KDat::fileBackup()
             // Rewind tape.
             status( i18n( "Rewinding tape..." ) );
             if ( !TapeDrive::instance()->rewind() ) {
-                KMessageBox::error( this, 
-                      i18n("Cannot rewind tape.\nBackup aborted."), 
+                KMessageBox::error( this,
+                      i18n("Cannot rewind tape.\nBackup aborted."),
                       i18n("Backup Error"));
                 status( i18n( "Backup aborted." ) );
                 return;
@@ -506,8 +515,8 @@ void KDat::fileBackup()
         // Go to end of tape.
         status( i18n( "Skipping to end of tape..." ) );
         if ( !TapeDrive::instance()->nextFile( TapeManager::instance()->getMountedTape()->getChildren().count() + 1 - TapeDrive::instance()->getFile() ) ) {
-            KMessageBox::error( this, 
-                      i18n("Cannot get to end of tape.\nBackup aborted."), 
+            KMessageBox::error( this,
+                      i18n("Cannot get to end of tape.\nBackup aborted."),
                       i18n("Backup Error"));
             status( i18n( "Backup aborted." ) );
             return;
@@ -557,7 +566,7 @@ void KDat::doVerify( bool restore )
             archive = archiveNode->getArchive();
 	    /* 2002-01-30 LEW */
 #ifdef DEBUG
-	    printf("KDat::doVerify: %d node of %s: ", i, 
+	    printf("KDat::doVerify: %d node of %s: ", i,
 		   (SelectableNode*)_tapeDriveNode->getText().latin1() );
             if( ((SelectableNode*)_tapeDriveNode->childAt( i ))->isSelected() ){
 	      printf("is completely selected\n");
@@ -714,10 +723,10 @@ void KDat::fileMountTape()
 
 void KDat::fileIndexTape()
 {
-    int result = KMessageBox::warningContinueCancel( this, 
-		       i18n( "The current tape index will be overwritten, continue?" ), 
+    int result = KMessageBox::warningContinueCancel( this,
+		       i18n( "The current tape index will be overwritten, continue?" ),
                        i18n( "Index Tape"), i18n("Overwrite"));
-    if ( result == KMessageBox::Continue) { 
+    if ( result == KMessageBox::Continue) {
         TapeManager::instance()->getMountedTape()->clear();
         IndexDlg dlg( TapeManager::instance()->getMountedTape(), this );
         if ( dlg.exec() == QDialog::Accepted ) {
@@ -770,9 +779,9 @@ void KDat::fileDeleteArchive()
             list.append( i.current()->getName() );
         }
 
-        QString msg = 
+        QString msg =
              i18n( "An archive cannot be removed from the middle of the tape. If\nthe archive '%1' is deleted then\nthe following archives will also be deleted:\n%2\n\nDelete all listed archives?" ).arg(archive->getName()).arg(list);
-        int result = KMessageBox::warningContinueCancel( this, 
+        int result = KMessageBox::warningContinueCancel( this,
              msg, i18n("Delete Archive"), i18n("Delete All"));
         if (result == KMessageBox::Continue) {
             tape->removeChild( archive );
@@ -784,9 +793,9 @@ void KDat::fileDeleteArchive()
         }
     } else {
         // This is the last (known) archive on the tape.
-        QString msg = 
+        QString msg =
              i18n( "Really delete the archive '%1'?" ).arg(archive->getName());
-        int result = KMessageBox::warningContinueCancel( this, 
+        int result = KMessageBox::warningContinueCancel( this,
                               msg, i18n("Delete Archive"), i18n("Delete"));
         if (result == KMessageBox::Continue) {
             tape->removeChild( archive );
@@ -820,7 +829,7 @@ void KDat::fileDeleteIndex()
 
     QString msg =
          i18n( "Really delete the index for '%1'?" ).arg(tape->getName());
-    int result = KMessageBox::warningContinueCancel( this, 
+    int result = KMessageBox::warningContinueCancel( this,
                     msg, i18n("Delete Tape Index"), i18n("Delete"));
     if (result == KMessageBox::Continue) {
         TapeManager::instance()->removeTape( tape );
@@ -854,10 +863,10 @@ void KDat::fileFormatTape()
         return;
     }
 
-    int result = KMessageBox::warningContinueCancel( this, 
+    int result = KMessageBox::warningContinueCancel( this,
                      i18n( "All data currently on the tape will be lost.\n"
-                           "Are you sure you want to continue?" ), 
-                     i18n("Format Tape"), i18n("Format")); 
+                           "Are you sure you want to continue?" ),
+                     i18n("Format Tape"), i18n("Format"));
     if (result == KMessageBox::Continue ) {
         QString name;
         name = i18n( "Tape created on %1" ).arg(  KGlobal::locale()->formatDate(QDate::currentDate(), true) );
@@ -942,8 +951,8 @@ void KDat::fileDeleteBackupProfile()
 
     QString msg =
          i18n("Really delete backup profile '%1'?").arg(backupProfile->getName());
-    int result = KMessageBox::warningContinueCancel( this, 
-                        msg, i18n("Delete backup profile"), i18n("Delete"));
+    int result = KMessageBox::warningContinueCancel( this,
+                        msg, i18n("Delete Backup Profile"), i18n("Delete"));
     if (result == KMessageBox::Continue) {
         BackupProfileManager::instance()->removeBackupProfile( backupProfile );
         emit status( i18n( "Backup profile deleted." ) );
@@ -997,7 +1006,7 @@ void KDat::setTapePresent( bool tapePresent, bool eject )
                 if ( TapeDrive::instance()->isReadOnly() ) {
                     KMessageBox::sorry( this, i18n( "This tape has not been formatted by KDat." ));
                 } else {
-                    int result = KMessageBox::questionYesNo( this, 
+                    int result = KMessageBox::questionYesNo( this,
                           i18n( "This tape has not been formatted by KDat.\n\nWould you like to format it now?" ));
                     if (result == KMessageBox::Yes) {
                         fileFormatTape();
@@ -1254,18 +1263,18 @@ void KDat::configureUI( Tape* tape )
         }
     }
     if ( canRestore ) {
-      // 2002-01-30 LEW: check Node *sel because we can have canRestore==true 
+      // 2002-01-30 LEW: check Node *sel because we can have canRestore==true
       // even if sel==NULL when a child is selected (see loop above).
       if( sel != (Node *)0x0 )
-      { 
-        for ( Node* parent = (Node*)sel->getParent(); 
-              ( parent ) && ( parent->getParent() ); 
+      {
+        for ( Node* parent = (Node*)sel->getParent();
+              ( parent ) && ( parent->getParent() );
               parent = (Node*)parent->getParent() ) {
             if ( parent->isType( Node::TapeNodeType ) ) {
                 canRestore = FALSE;
             }
         }
-      } 
+      }
       // 2002-01-30 LEW: see if we ever get here...
       else
 	{
@@ -1321,7 +1330,7 @@ void KDat::create_backup_dialog()
 {
   /* 2002-01-24 LEW:  start of backup-cancel dialog */
   static QString stop_button_text, stop_button_caption;
-  stop_button_text = 
+  stop_button_text =
     i18n("Click \"CANCEL\" to stop the backup process.\n"
 	 "For example, you may quickly see that the size of\n"
 	 "the files you selected will exceed the size of the\n"
@@ -1340,23 +1349,23 @@ void KDat::create_backup_dialog()
 
   _lbl = new QLabel( stop_button_text, _backupdialog );
   //  _lbl->setGeometry( QRect( 30, 20, 350, 140 ) );  /* 2002-01-28 LEW */
-  _lbl->setGeometry( QRect( 30, 20, 350, 200 ) ); 
+  _lbl->setGeometry( QRect( 30, 20, 350, 200 ) );
 
-  _cancel = new QPushButton( i18n( "CANCEL" ), _backupdialog );
+  _cancel = new QPushButton( i18n( "&Cancel" ), _backupdialog );
   _cancel->setFixedSize( 80, _cancel->sizeHint().height() );
   _cancel->setEnabled( TRUE );
   /* 2002-01-24 LEW: looks like we can't increase the button width
      to accomodate a wider message :( */
   //  _cancel->setGeometry( QRect( 50, 170, 0, 0 ) );   /* 2002-01-28 LEW */
-  _cancel->setGeometry( QRect( 50, 230, 0, 0 ) ); 
+  _cancel->setGeometry( QRect( 50, 230, 0, 0 ) );
   connect( _cancel, SIGNAL( clicked() ), this, SLOT( backupCancel() ) );
 
-  _continue = new QPushButton( i18n( "Continue" ), _backupdialog );
+  _continue = new QPushButton( i18n( "C&ontinue" ), _backupdialog );
   _continue->setFixedSize( 80, _continue->sizeHint().height() );
   _continue->setEnabled( TRUE );
   _continue->setDefault( TRUE );
   //  _continue->setGeometry( QRect( 200, 170, 0, 0 ) );   /* 2002-01-28 LEW */
-  _continue->setGeometry( QRect( 200, 230, 0, 0 ) ); 
+  _continue->setGeometry( QRect( 200, 230, 0, 0 ) );
   connect( _continue, SIGNAL( clicked() ), this, SLOT( backupContinue() ) );
 
   _backupdialog->show();
