@@ -90,7 +90,7 @@ TapeInfoWidget::TapeInfoWidget( QWidget* parent, const char* name )
     _spaceUsed = new QLabel( "???", this );
     _spaceUsed->setFixedHeight( _spaceUsed->sizeHint().height() );
 
-    _apply = new QPushButton( i18n( "Apply" ), this );
+    _apply = new QPushButton( i18n( "&Apply" ), this );
     _apply->setFixedSize( 80, _apply->sizeHint().height() );
     _apply->setEnabled( FALSE );
 
