@@ -1,6 +1,6 @@
 /*
- * $Revision: 1.4 $
- * $Date: 2000/08/05 19:45:51 $
+ * $Revision: 1.10 $
+ * $Date: 2001/10/20 05:36:44 $
  * 
  * KTreeView class interface
  * 
@@ -27,12 +27,12 @@
 #define KDE_KTREE_VIEW_H
 
 #include <qpixmap.h>			/* used in items */
-#include <qstack.h>			/* used to specify tree paths */
+#include <qptrstack.h>			/* used to specify tree paths */
 #include <qstring.h>			/* used in items */
-#include <qtableview.h>			/* base class for widget */
+#include <qgridview.h>			/* base class for widget */
 
 // use stack of strings to represent path information
-typedef QStack<QString> KPath;
+typedef QPtrStack<QString> KPath;
 
 class KTreeView;			/* forward declaration */
 
@@ -398,7 +398,7 @@ typedef bool (*KForEvery)
   signal void collpased(int) - emitted when an item in the tree is collapsed;
   sends the index of the item
   */
-class KTreeView : public QTableView
+class KTreeView : public QGridView
 {
     friend class KTreeViewItem;
     Q_OBJECT
@@ -792,8 +792,6 @@ protected:
      */
     void appendChildItem(KTreeViewItem* theParent,
 			 KTreeViewItem* theChild);
-    virtual int cellHeight(int row);
-    virtual int cellWidth(int col);
     void changeItem(KTreeViewItem* toChange,
 		    int itemRow, const QString & newText,
 		    const QPixmap* newPixmap);
