@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: debAptInterface.cpp,v 1.28 2002/01/27 06:30:42 toivo Exp $
+//      $Id: debAptInterface.cpp,v 1.32.2.1 2002/12/13 15:20:21 toivo Exp $
 //
 // Author: Toivo Pedaste
 //
@@ -35,7 +35,7 @@ DEBAPT::DEBAPT():DEB()
 
   locatedialog->dLocations(1, 8, this, i18n("D"),
 			   "Deb", "*.deb",
-			   i18n("Location of directories containing Debian packages"));
+			   i18n("Location of Directories Containing Debian Packages"));
   connect(locatedialog,SIGNAL(returnVal(LcacheObj *)),
 	  this,SLOT(setAvail(LcacheObj *)));
   locatedialog->apply_slot();
@@ -51,6 +51,8 @@ DEBAPT::DEBAPT():DEB()
   paramsUninst.append(new param(i18n("Assume yes"),TRUE,FALSE,"--yes"));
   paramsUninst.append(new param(i18n("Test (do not uninstall)"),FALSE,FALSE,"-s"));
 
+  env = "DEBIAN_FRONTEND=readline; export DEBIAN_FRONTEND; ";
+
   noFetch = TRUE;
 }
 
@@ -63,7 +65,7 @@ DEBAPT::~DEBAPT()
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-bool DEBAPT::isType(char *buf, const QString &)
+bool DEBAPT::isType(char *, const QString &)
 {
   return false;
 }
@@ -100,14 +102,14 @@ void DEBAPT::updateS()
 
 void DEBAPT::upgradeS()
 {
- kprun->run("apt-get upgrade", "APT upgrade");
+ kprun->run(env + "apt-get upgrade", "APT upgrade");
  if (kprun->exec())
    kpackage->management->collectData(TRUE);
  }
 
 void DEBAPT::fixupS()
 {
- kprun->run("apt-get -f install", "APT fixup");
+ kprun->run(env + "apt-get -f install", "APT fixup");
  if (kprun->exec())
    kpackage->management->collectData(TRUE);
 }
@@ -324,7 +326,7 @@ QStringList DEBAPT::getFileList(packageInfo *p)
 //////////////////////////////////////////////////////////////////////////////
 QString DEBAPT::doUninstall(int uninstallFlags, QString packs, bool &test)
 {
-  QString s = "apt-get remove ";
+  QString s = env + "apt-get remove ";
   s += setOptions(uninstallFlags, paramsUninst);
   s +=  packs;
 
@@ -349,10 +351,14 @@ QString DEBAPT::install(int installFlags, QPtrList<packageInfo> *p,
     QString fname = i->fetchFilename();
 
     if (!file.isEmpty()) {
+      files += "'";
       files += file;
+      files += "'";
       files += " ";
     } else if (fname != "") {
+      packs += "'";
       packs += fname;
+      packs += "'";
       packs += " ";
     }
   }
@@ -366,7 +372,7 @@ QString DEBAPT::install(int installFlags, QPtrList<packageInfo> *p,
 
 QString DEBAPT::doInstall(int installFlags, QString packs, bool &test)
 {
-  QString s = "apt-get install ";
+  QString s = env + "apt-get install ";
   s += setOptions(installFlags, paramsInst);
   s +=  packs;
 
