@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: fbsdInterface.cpp,v 1.36 2002/08/15 16:06:16 binner Exp $
+//      $Id: fbsdInterface.cpp,v 1.36.2.1 2003/06/12 19:25:34 fawcett Exp $
 //
 // Author: Alex Hayward
 // xelah@ferret.lmh.ox.ac.uk
@@ -372,7 +372,7 @@ void fbsdInterface::listPackages(QPtrList<packageInfo> *pki) {
 
 	const char *space = strchr(scan->cats, ' ');
 	if (space) {
-          a->insert("group", new QString(QString(scan->cats).left(space - scan->cats + 1)));
+          a->insert("group", new QString(QString(scan->cats).left(space - scan->cats)));
 	  a->insert("also in", new QString(space+1));
 	} else a->insert("group", new QString(scan->cats));
 
@@ -506,7 +506,7 @@ void fbsdInterface::listInstalledPackages(QPtrList<packageInfo> *pki) {
 
 	const char *space = strchr(inditem->cats, ' ');
 	if (space) {
-          a->insert("group", new QString(QString(inditem->cats).left(space - inditem->cats + 1)));
+          a->insert("group", new QString(QString(inditem->cats).left(space - inditem->cats)));
 	  a->insert("also in", new QString(space+1));
 	} else a->insert("group", new QString(inditem->cats));
 
