@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-// 	$Id: fbsdInterface.h,v 1.10 2001/09/26 16:33:31 mlaurent Exp $
+// 	$Id: fbsdInterface.h,v 1.11 2002/06/07 11:44:59 coolo Exp $
 //
 // Author: Alex Hayward
 //
@@ -27,7 +27,7 @@ class fbsdInterface : public pkgInterface
 public:
   fbsdInterface();
   ~fbsdInterface();
-  
+
   void init();
 
   bool isType(char *buf, const QString &fname);
@@ -42,7 +42,7 @@ public:
 
   QStringList FindFile(const QString &name);
   void collectDepends(packageInfo *p, const QString &name, int src);
-  bool parseName(QString name, QString *n, QString *v);
+  bool parseName(const QString& name, QString *n, QString *v);
 
   void listInstalledPackages(QPtrList<packageInfo> *pki);
   void listPackages(QPtrList<packageInfo> *pki);
@@ -55,7 +55,7 @@ private:
   /**
    * @short Add the name and version identifiers to a QDict<QString>.
    *
-   * name is parsed in to name and version and these are added to 
+   * name is parsed in to name and version and these are added to
    * d. Errors are handled.
    */
   void addNV(QDict<QString> *d, const QString &name);
