@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: findf.h,v 1.12 2001/07/28 08:14:05 mlaurent Exp $ 
+//      $Id: findf.h,v 1.12.6.1 2003/03/13 00:05:21 rnolden Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -16,13 +16,13 @@
 #include <qwidget.h>
 #include <qframe.h>
 #include <qlabel.h>
-#include <qfiledlg.h> 
-#include <qgrpbox.h> 
-#include <qchkbox.h>
+#include <qfiledialog.h> 
+#include <qgroupbox.h> 
+#include <qcheckbox.h>
 #include <qlayout.h> 
 
 // KDE headers
-#include <kapp.h>
+#include <kapplication.h>
 #include <kmenubar.h>
 #include <klistview.h> 
 #include <kdialogbase.h>
