@@ -4,9 +4,9 @@
 
 #include <vector>
 
-#include "qobject.h"
-#include "qfile.h"
-#include "qtextstream.h"
+#include <qobject.h>
+#include <qfile.h>
+#include <qtextstream.h>
 #include "../config.h"
 #include <kio/job.h>
 
@@ -17,7 +17,7 @@ class Kio: public QObject
 public:
   Kio();
 
-  bool download(QString from, QString to);
+  bool download(const KURL & from, const QString & to);
 
 private:
   bool worked;
@@ -32,8 +32,9 @@ class Kiod: public QObject
 
 public:
   Kiod();
+    ~Kiod();
 
-  bool listDir(QString url, QString fname);
+  bool listDir(QString url, QString fname, bool subdirs);
 
 private:
   QFile *file;
