@@ -5,13 +5,11 @@
 
 #include <qmultilineedit.h>
 #include <qstringlist.h>
-#include <qevent.h>
-#include <qdialog.h>
 #include <qlayout.h>
 #include <qlabel.h>
 
 #include <klocale.h>
-
+#include <kdialogbase.h>
 #include <kpackage.h>
 #include <kpPty.h>
 
@@ -43,9 +41,9 @@ signals:
 
 //////////////////////////////////////////////////////////////////////////////
 
-class kpRun: public QDialog
+class kpRun: public KDialogBase
 {
-  Q_OBJECT;
+  Q_OBJECT
 
 public:
   kpRun(QWidget *parent = 0);
@@ -57,10 +55,8 @@ public slots:
   void slotCancel();
 
 private:
-  QBoxLayout *layout;
   kpTerm *term;
   QLabel *title;
-  QPushButton *cancelButton;
 };	
 //////////////////////////////////////////////////////////////////////////////
 #endif
