@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////////////
-//      $Id: kpackage.cpp,v 1.76 2002/01/23 15:48:17 mueller Exp $
+//      $Id: kpackage.cpp,v 1.80 2002/10/09 15:19:03 toivo Exp $
 // File  : kpackage.cpp
 // Author: Damyan Pepper
 //         Toivo Pedaste
@@ -107,12 +107,12 @@ void KPKG::setupMenu()
 				  actionCollection());
   recent->loadEntries( config );
 
- pack_find = new KAction( i18n("Find &Package"), "find",
+ pack_find = new KAction( i18n("Find &Package..."), "find",
 		       KStdAccel::key(KStdAccel::Find), kpackage,
 		       SLOT(find()), actionCollection(), "pack_find");
   pack_find->plugAccel(keys);
 
-  pack_findf = new KAction( i18n("Find &File"), "filefind",
+  pack_findf = new KAction( i18n("Find &File..."), "filefind",
 		       0, kpackage,
 		       SLOT(findf()), actionCollection(), "pack_findf");
   pack_findf->plugAccel(keys);
@@ -146,7 +146,7 @@ void KPKG::setupMenu()
 		       SLOT(clearMarked()), actionCollection(), "kpack_clear"))->plugAccel(keys);
 
   pack_install = new KAction( i18n("&Install"), QString::null,
-		       0, kpackage->management, 
+		       0, kpackage->management,
 		       SLOT(installSingleClicked()), actionCollection(), "install_single");
   pack_install->plugAccel(keys);
   pack_install->setEnabled(false);
@@ -459,7 +459,7 @@ void KPACKAGE::fileOpen()		// file->quit selected from menu
 
     box = getFileDialog(i18n("Select Package"));
 
-    box->show();
+    box->exec();
 
     if (!box->result())   /* cancelled */
       return;
@@ -525,11 +525,12 @@ pkgInterface *KPACKAGE::pkType(QString fname)
 
 /////////////////////////////////////////////////////////////////////////
 
-void KPACKAGE::openNetFiles (QStringList urls )
+void KPACKAGE::openNetFiles (QStringList urls, bool install )
 {
   QStringList files;
   int i;
   QPtrList<packageInfo> **lst = new QPtrList<packageInfo>*[kpinterfaceN];
+  packageInfo *pk = 0;
 
   kdDebug() << "openNetFiles\n";
 
@@ -544,9 +545,8 @@ void KPACKAGE::openNetFiles (QStringList urls )
       for (QStringList::Iterator t = files.begin(); t != files.end(); ++t) {
 	pkgInterface *type = pkType(*t);
 	if (type ==  kpinterface[i]) {
-	  packageInfo *pk = type->getPackageInfo('u', *t, 0);
+	  pk = type->getPackageInfo('u', *t, 0);
 	  if (pk) {
-	    kdDebug() << "TTT=" << *t << "\n";
 	    pk->pkgFileIns(*t);
 	    lst[i]->insert(0,pk);
 	  }
@@ -555,15 +555,32 @@ void KPACKAGE::openNetFiles (QStringList urls )
     }
   }
 
-  for (i = 0; i < kpinterfaceN; i++) {
-    if (kpinterface[i]) {
-      if (lst[i]->count() > 0) {
-	kpinterface[i]->installation->setup(lst[i],kpinterface[i]->head);
-	if (kpinterface[i]->installation->exec()) {
-	  for (packageInfo *inf = lst[i]->first(); inf != 0; inf = lst[i]->next()) {
-	     kpackage->management->updatePackage(inf,TRUE);
+  if (install)
+    for (i = 0; i < kpinterfaceN; i++) {
+      if (kpinterface[i]) {
+	if ( lst[i]->count() > 0) {
+	  kpinterface[i]->installation->setup(lst[i],kpinterface[i]->head);
+	  if (kpinterface[i]->installation->exec()) {
+	    for (packageInfo *inf = lst[i]->first(); inf != 0; inf = lst[i]->next()) {
+	      kpackage->management->updatePackage(inf,TRUE);
+	    }
 	  }
 	}
+      }
+    } else {
+      if (pk) {
+	KPLVItem *pt = pk->item;
+	// NOT the best place for this CODE
+	kpackage->management->tabChanged(Opts::ALL);
+	if (pt)
+	  kpackage->management->packageHighlighted(pt);
+      }
+    }
+
+  // Dealloc memory
+  for (i = 0; i < kpinterfaceN; i++) {
+    if (kpinterface[i]) {
+      if ( lst[i]->count() > 0) {
 	delete lst[i];
       }
     }
@@ -571,9 +588,9 @@ void KPACKAGE::openNetFiles (QStringList urls )
   delete [] lst;
 }
 
-void KPACKAGE::openNetFile(const KURL &url )
+void KPACKAGE::openNetFile(const KURL &url, bool install )
 {
-  openNetFiles(url.url());
+  openNetFiles(url.url(), install);
 }
 
 //    KMimeMagic *magic = KMimeMagic::self();
@@ -602,16 +619,6 @@ QString KPACKAGE::getFileName(const KURL & url, QString &cacheName )
 
 	QString cacheFile = tmpd + url.fileName();
 
-	//	QString file = url.path();
-	//	int pt = file.findRev('/'); // could use KURL::fileName instead (David)
-	//	pt++;
-	//	if (pt >= 0) {  			// file name for cache
-	//	  cacheFile = tmpd + file.right(file.length() - pt);
-	//	} else {
-	//	  cacheFile = tmpd + file;
-	//	}
-
-
 	cacheName = cacheFile;
 	QFileInfo f(cacheFile);
 	if (f.exists() && (opts->DCache != Opts::NEVER)) {
