@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////////////////
-// $Id: kpackage.h,v 1.37 2002/10/08 14:49:39 toivo Exp $	
+// $Id: kpackage.h,v 1.37.2.1 2003/03/13 00:05:21 rnolden Exp $	
 // File  : kpackage.h
 // Author: Toivo Pedaste
 //
@@ -22,11 +22,11 @@
 #include <qwidget.h>
 #include <qframe.h>
 #include <qlabel.h>
-#include <qfiledlg.h> 
-#include <qgrpbox.h> 
+#include <qfiledialog.h> 
+#include <qgroupbox.h> 
 
 // KDE headers
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdebug.h>
 #include <kconfig.h>
 #include <kurl.h>
