@@ -1,5 +1,5 @@
 ///////////////////////////////////////////////////////////////////////////////
-// $Id: main.cpp,v 1.30 2001/12/28 00:58:03 mueller Exp $	
+// $Id: main.cpp,v 1.32 2002/10/08 14:49:39 toivo Exp $	
 // File  : main.cpp
 // Author: Damyan Pepper
 // Author: Toivo Pedaste
@@ -28,9 +28,9 @@
 #include "kissInterface.h"
 #include "slackInterface.h"
 #include "fbsdInterface.h"
-#ifdef HAVE_RPM
+//#ifdef HAVE_RPM
 #include "rpmInterface.h"
-#endif
+//#endif
 
 
 static const char *description = 
@@ -59,9 +59,9 @@ pkgInterface *kpinterface[kpinterfaceN];
 int main(int argc, char **argv)
 {
   KAboutData aboutData( "kpackage", I18N_NOOP("KPackage"), 
-			  VERSION, description, KAboutData::License_GPL, 
+			VERSION, description, KAboutData::License_GPL, 
 			//    VERSION, description, 0, 
-    "(c) 1999-2001, Toivo Pedaste");
+			"(c) 1999-2001, Toivo Pedaste");
   KCmdLineArgs::init( argc, argv, &aboutData );
   aboutData.addAuthor( "Toivo Pedaste",0, "toivo@ucs.uwa.edu.au");
   KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
@@ -74,7 +74,6 @@ int main(int argc, char **argv)
 
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
   QString remoteHost = args->getOption("remote");
-  kdDebug() << "r=" << args->getOption("remote") << "\n";
 
   if (remoteHost.isEmpty() || remoteHost == "localhost") {
     hostName = "";
@@ -93,13 +92,13 @@ int main(int argc, char **argv)
   kpinterface[j++] = new DEBDPKG();
   kpinterface[j++] = new DEBAPT();
   kpinterface[j++] = new KISS();
-#ifdef HAVE_RPM
+  //#ifdef HAVE_RPM
   kpinterface[j++] = new RPM();
-#endif
+  //#endif
   kpinterface[j++] = new fbsdInterface();
   kpinterface[j++] = new SLACK(); // Also catched BSD packages...
 
-  kdDebug() << "R=" << hostName << "\n";
+  kdDebug() << "Hostname=" << hostName << "\n";
   opts = new Opts(hostName);
 
   if ( app.isRestored() ) {
@@ -115,9 +114,12 @@ int main(int argc, char **argv)
   kpkg->setCaption(hostName);
 
   if (args->count()) {		// an argument has been given
-      kpackage->openNetFile(args->url(0)); 
-                        // install package from argument
-  }  else {			// otherwise
+    QStringList files;
+    for(int i = 0; i < args->count(); i++) {
+      files.append(args->url(i).url());
+    }
+    kpackage->openNetFiles(files, FALSE); 
+  }  else {	
     if (!kpkg->prop_restart)
       kpackage->setup();
   }
