@@ -1,18 +1,18 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: procbuf.h,v 1.4 2000/12/13 14:14:44 toivo Exp $ 
+//      $Id: procbuf.h,v 1.6 2002/04/22 18:48:35 arbab Exp $ 
 //
 // Author: Toivo Pedaste
 //
 #include "../config.h"
 #include <kprocess.h>
-#include <qdialog.h> 
+#include <kdialog.h> 
 #include <qobject.h> 
 #include <qtimer.h>
 
 #ifndef PROCBUF
 #define PROCBUF
 
-class Modal : public QDialog {
+class Modal : public KDialog {
   Q_OBJECT
 public:
   Modal(QString msg, QWidget *parent, const char * name );
@@ -21,7 +21,7 @@ public:
 
 class procbuf: public QObject
 {
-  Q_OBJECT;
+  Q_OBJECT
 
 public:
   procbuf();
