@@ -1,12 +1,14 @@
 /*****************************************************************/
-/* 	$Id: rpmMessages.c,v 1.14 2000/09/24 14:15:36 toivo Exp $ */
+/* 	$Id: rpmMessages.c,v 1.19 2001/11/05 12:55:39 toivo Exp $ */
 #include "../config.h"
 
 #ifdef HAVE_RPM
 #include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
-
+/* stupid RPM headers! */
+#include <sys/types.h>  
+typedef __off64_t off64_t;
 #include <rpm/rpmlib.h>
 #include "rpmMessages.h"
 
@@ -16,31 +18,33 @@ static int minLevel = RPMMESS_NORMAL;
  char *specedit = NULL;    
 #  endif
 
-void rpmIncreaseVerbosity(void) 
+void kpackage_rpmIncreaseVerbosity(void) 
 {
   minLevel--;
 }
 
-void rpmSetVerbosity(int level) 
+void kpackage_rpmSetVerbosity(int level) 
 {
   minLevel = level;
 }
 
-int rpmGetVerbosity(void)
+int kpackage_rpmGetVerbosity(void)
 {
   return minLevel;
 }
 
-int rpmIsDebug(void)
+int kpackage_rpmIsDebug(void)
 {
   return (minLevel <= RPMMESS_DEBUG);
 }
 
-int rpmIsVerbose(void)
+int kpackage_rpmIsVerbose(void)
 {
   return (minLevel <= RPMMESS_VERBOSE);
 }
 
+/* Awful hack... */
+#if RPM_V1 != 3 || RPM_V2 != 0 || RPM_V3 != 6
 #  if RPM_V1 >= 4 || (RPM_V1 >= 3 && RPM_V2 == 0 && RPM_V3 >= 1)
 void rpmMessage(int level,  const char * format, ...) 
 #  else
@@ -68,6 +72,7 @@ void rpmMessage(int level, char * format, ...)
 	  
 	case RPMMESS_DEBUG:
 	  vsprintf(buffer, f, args);
+	  return;
 	  break;
 	  
 	case RPMMESS_WARNING:
@@ -98,6 +103,7 @@ void rpmMessage(int level, char * format, ...)
       rpmBuff(buffer);
     }
 }
+#endif
 
 #  if RPM_V1 >= 3 && RPM_V2 == 0 && RPM_V3 < 2
 
