@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: slackInterface.h,v 1.19 2001/09/26 16:33:31 mlaurent Exp $ 
+//      $Id: slackInterface.h,v 1.20 2002/06/07 11:44:59 coolo Exp $
 //
 // Author: Toivo Pedaste
 //
@@ -26,7 +26,7 @@ class SLACK: public pkgInterface
 public:
   SLACK();
   ~SLACK();
-  
+
   bool isType(char *buf, const QString &fname);
 
   packageInfo *getPackageInfo(char mode, const QString &name,
@@ -34,7 +34,7 @@ public:
   QStringList getFileList(packageInfo *p);
 
   QStringList FindFile(const QString &name);
-  bool parseName(QString name, QString *n, QString *v);
+  bool parseName(const QString& name, QString *n, QString *v);
 
   QString install(int installFlags, QPtrList<packageInfo> *plist, bool &test);
 
@@ -45,7 +45,7 @@ public slots:
 private:
   packageInfo* collectInfo(const char *inp, int insState);
    void listInstalledPackages(QPtrList<packageInfo> *pki);
- 
+
   QString doUninstall(int installFlags, QString packs, bool &test);
   QString doInstall(int installFlags, QString packs, bool &test);
 
