@@ -174,6 +174,8 @@ AboutDlg::AboutDlg (QWidget* parent)
   c3l->addWidget(copyright3, 0, AlignLeft|AlignBottom);
   copyLayout->addStretch (5);
 
+#if 0
+
   QBoxLayout* homePageLayout = new QHBoxLayout (0);
 
   QLabel* homePage1 = new QLabel (i18n ("Visit %1's homepage at ").arg (mAppName), page);
@@ -198,6 +200,7 @@ AboutDlg::AboutDlg (QWidget* parent)
 
   topLayout->addStretch (-1);
   topLayout->addLayout (homePageLayout);
+#endif
 
   license->setMinimumHeight (license->heightForWidth(max_min_width));
   //   description->setMinimumHeight (description->heightForWidth(max_min_width));
