@@ -5,7 +5,7 @@
     Copyright (C) 1997-2000 Peter Putzer
                             putzer@kde.org
 
-	$Id: TopWidget.cpp,v 1.110 2002/09/01 08:46:42 mlaurent Exp $
+	$Id: TopWidget.cpp,v 1.110.2.1 2003/05/19 02:52:56 mueller Exp $
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of version 2 of the GNU General Public License
@@ -94,7 +94,7 @@ namespace Status
   enum {
     Changed, Checklist, Writable
   };
-}; // namespace Status
+} // namespace Status
 
 KSVTopLevel::KSVTopLevel()
   : KMainWindow(0, 0L, WStyle_ContextHelp|WDestructiveClose),
