@@ -98,6 +98,7 @@ void KSVConfigWizard::chooseDistribution(int which)
 
     case RedHat:
     case Mandrake:
+	 case Conectiva:
       rlpath = "/etc/rc.d";
       spath = "/etc/rc.d/init.d";
       break;
@@ -121,5 +122,4 @@ void KSVConfigWizard::chooseDistribution(int which)
     setAppropriate (mPathsPage, true);
 }
 
-#include "configwizard.moc"
 #include "ksvconfigwizard.moc"
