@@ -2,7 +2,7 @@
 #define _KERROR_H
 
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 
 class KError: public QObject {
