@@ -2,16 +2,10 @@
 #define nisDefaultsPage_included
 
 #include <kcontainer.h>
+#include <klocale.h>
 #include <qlineedit.h>
 #include <qcheckbox.h>
-#include <sys/types.h> 
-
-#define NONNISPWD "Local passwd source"
-#define NONNISGRP "Local group source"
-#define NISPWD    "NIS passwd source"
-#define NISGRP    "NIS group source"
-#define NISMINUID "NIS minimum UID"
-#define NISMINGID "NIS minimum GID"
+#include <sys/types.h>
 
 class nisDefaultsPage : public QWidget {
     Q_OBJECT
@@ -25,7 +19,7 @@ public:
   ~nisDefaultsPage();
 
   void    addOne(KContainerLayout *layout, int row, bool homogeneous,
-                 bool expand, bool fill); 
+                 bool expand, bool fill);
 
   QString getPasswdSrc() const;
   QString getNISPasswdSrc() const;
