@@ -1,22 +1,18 @@
 #ifndef ADDNORET_H
 #define ADDNORET_H
 #include "ftpaccess.h"
-#include "InputFileCtl.h"
 #include <qpushbutton.h>
+#include <kurlrequesterdlg.h>
 
-class AddNoRet : public QWidget {
+
+class AddNoRet : public KURLRequesterDlg {
 	Q_OBJECT
 public:
 	AddNoRet(QWidget *parent=0, char *wname=0);
 	~AddNoRet();
 public slots:
-	void okButtonPressed();
-	void cancelButtonPressed();
+	void slotOk();
 signals:
 	void noRetAdded(const QString &);
-private:
-	InputFileCtl *	filename;
-	QPushButton *	ok;
-	QPushButton *	cancel;
 };
 #endif
