@@ -1,22 +1,17 @@
 #ifndef ADDRCPT_H
 #define ADDRCPT_H
 #include "ftpaccess.h"
-#include "InputCtl.h"
 #include <qpushbutton.h>
+#include <klineeditdlg.h>
 
-class AddRCPT : public QWidget {
+class AddRCPT : public KLineEditDlg {
 	Q_OBJECT
 public:
 	AddRCPT(QWidget *parent=0, char *wname=0);
 	~AddRCPT();
 public slots:
-	void okButtonPressed();
-	void cancelButtonPressed();
+	void slotOk();
 signals:
 	void RCPTAdded(QString);
-private:
-	InputCtl *	email;
-	QPushButton *	ok;
-	QPushButton *	cancel;
 };
 #endif
