@@ -3,7 +3,7 @@
 
 #include "ftpaccess.h"
 #include "RatiosBase.h"
-#include <kapp.h>
+#include <kapplication.h>
 
 class Ratios : public RatiosBase {
 	Q_OBJECT
