@@ -12,21 +12,21 @@ TimeValidator::~TimeValidator()
 }
 QValidator::State TimeValidator::validate(QString &input, int &pos) const
 {
-	char c;
-	for(unsigned int i=0;i<strlen(input);i++) {
+	QChar c;
+	for(unsigned int i = 0; i < input.length();i++) {
 		c=input.mid(i,1).latin1()[0];
 		if(!isdigit(c) && c!='-')
 			return QValidator::Invalid;
 	}
-	if(strchr(input,'-') && (strchr(input,'-')-input)>4) // - has to be at pos. 5 or lower (backspace editing must work)
+	if(input.find('-') > 4) // - has to be at pos. 5 or lower (backspace editing must work)
 		return QValidator::Invalid;
-	if(pos==4 && strlen(input)==4 && !input.find('-')) { // Add the - automatically...
+	if(pos==4 && input.length()==4 && !input.find('-')) { // Add the - automatically...
 		input+="-";
 		pos=5;
 	}
-	if(strchr(input,'-')!=strrchr(input,'-')) // we want exactly one -
+	if(input.contains('-') == 1) // we want exactly one -
 		return QValidator::Invalid;
-	if(strlen(input)!=9 || input[4]!='-' || strlen(input)==0) // Working time = xxxx-xxxx or empty
+	if(input.length()!=9 || input[4]!='-' || input.isEmpty()) // Working time = xxxx-xxxx or empty
 		return QValidator::Acceptable;
 	return QValidator::Valid;
 }
