@@ -27,7 +27,7 @@
 class GeneralPage : public GeneralPageBase, public KXPage
 {
   Q_OBJECT
-  Q_PROPERTY( QString quickHelp READ quickHelp );
+  Q_PROPERTY( QString quickHelp READ quickHelp )
 public:
 
   GeneralPage(QWidget *parent=0, const char *name=0);
