@@ -27,8 +27,10 @@
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
 
+#include <config.h>
+
 #include <X11/Xlib.h>
-#ifndef __osf__
+#ifdef HAVE_X11_EXTENSIONS_XF86MISC_H
 #include <X11/extensions/xf86misc.h>
 #endif
 
@@ -332,7 +334,7 @@ void KXData::loadPointerData()
 {
     // ### hardcoded
 
-#ifndef __osf__
+#ifndef HAVE_X11_EXTENSIONS_XF86MISC_H
     m_pointerModels.append( KXPointerModel( i18n( "Generic PS/2" ), "PS/2",
                                             MTYPE_PS_2 ) );
     m_pointerModels.append( KXPointerModel( i18n( "Generic PS/2 Wheelmouse" ), "PS/2",
@@ -373,7 +375,7 @@ void KXData::loadPointerData()
                                             KX_Bus ) );
 
     m_pointerModels.append( KXPointerModel( "USB mouse", "USB", MTYPE_IMPS2, // ### ???
-                                            KX_USB ) );
+                                            KX_USB, 3, 1 ) );
 
     m_currentPointers.append( KXPointerData( m_pointerModels[ 0 ],
                               QString::fromLatin1( "/dev/psaux" ) ) ); // one mouse default. fixme?
