@@ -21,7 +21,7 @@
 
 #include <qstring.h>
 #include <qstringlist.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qdict.h>
 #include <qvaluelist.h>
 #include <qmap.h>
