@@ -23,7 +23,7 @@
 #include <qwidgetstack.h>
 #include <qstatusbar.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdialog.h>
 #include <kglobal.h>
 #include <kdebug.h>
