@@ -26,7 +26,7 @@
 class VideoCardPage : public VideoCardPageBase, public KXPage
 {
     Q_OBJECT
-    Q_PROPERTY( QString quickHelp READ quickHelp );
+    Q_PROPERTY( QString quickHelp READ quickHelp )
 public:
     VideoCardPage( QWidget *parent, const char *name = 0 );
     virtual ~VideoCardPage();
