@@ -161,8 +161,10 @@ bool liloconf::probe()
 	images.clear();
 	/* Set some reasonable defaults... */
 	// Try to figure out the boot device first...
-	if(drives.contains("/dev/hda"))
+	if(drives.contains("/dev/hda")) {	
 		defaults += "boot=/dev/hda"; // 1st IDE/ATAPI harddisk
+		defaults += "lba32";	// otherwise it is assumed
+	}
 	else if(drives.contains("/dev/sda")) {
 		defaults += "boot=/dev/sda"; // 1st SCSI harddisk
 		defaults += "linear"; // some SCSI disks need this
@@ -176,7 +178,8 @@ bool liloconf::probe()
 		defaults += "boot=Insert_your_boot_device_here"; // shouldn't happen
 	defaults += "prompt";
 	defaults += "timeout=50";
-	defaults += "message=/boot/message";
+        if(!access("/boot/message", F_OK))
+		defaults += "message=/boot/message";
 	defaults += "root=" + root;
 
 	/* Scan for available operating systems...
@@ -219,20 +222,34 @@ bool liloconf::probe()
 				label = label.right(label.length()-1-label.rfind('/'));
 		}	
 		// Check if we have an initial ramdisk (initrd) for this kernel...
-		String initrd;
-		if((*it).contains("vmlinuz"))
-			initrd=(*it).replace("vmlinuz", "initrd")+".img";
-		else if((*it).contains("vmlinux"))
-			initrd=(*it).replace("vmlinux", "initrd")+".img";
-		else if((*it).contains("kernel"))
-			initrd=(*it).replace("kernel", "initrd")+".img";
-		else if((*it).contains("linux"))
-			initrd=(*it).replace("linux", "initrd")+".img";
-		else
-			initrd="/boot/initrd-"+version+".img";
-
-		if(access(initrd, F_OK)) // Doesn't exist
-			initrd="";
+		String initrd1; // first guess
+		String initrd2; // second guess
+		if((*it).contains("vmlinuz")) {
+			initrd1=(*it).replace("vmlinux", "initrd")+".img";
+			initrd2=(*it).replace("vmlinuz", "initrd.img");
+		}	
+		else if((*it).contains("vmlinux")) {
+			initrd1=(*it).replace("vmlinux", "initrd")+".img";
+			initrd2=(*it).replace("vmlinuz", "initrd.img");
+		}
+		else if((*it).contains("kernel")) {
+			initrd1=(*it).replace("kernel", "initrd")+".img";
+			initrd2=(*it).replace("vmlinuz", "initrd.img");
+		}
+		else if((*it).contains("linux")) {
+			initrd1=(*it).replace("linux", "initrd")+".img";
+			initrd2=(*it).replace("vmlinuz", "initrd.img");
+		}
+		else {
+			initrd1="/boot/initrd-"+version+".img";
+			initrd2="/boot/initrd.img-"+version;
+		}
+		
+		String initrd = "";
+		if(!access(initrd1, F_OK))
+		    initrd = initrd1;
+		else if(!access(initrd2, F_OK))
+		    initrd = initrd2;    
 
 		if(label.size()>15) // LILO can't handle this
 			if(label.contains("enterprise"))
