@@ -19,10 +19,17 @@ Expert::~Expert()
 }
 void Expert::update()
 {
+	bool blocked = signalsBlocked();
+	blockSignals(true);
 	edit->setText(((String)*lilo).cstr());
+	blockSignals(blocked);
 }
 void Expert::saveChanges()
 {
 	lilo->set(edit->text().latin1());
 }
 
+void Expert::makeReadOnly()
+{
+    edit->setEnabled( false );
+}
