@@ -23,22 +23,27 @@ Images::Images(liloconf *l, QWidget *parent, const char *name):QWidget(parent, n
 	layout->addWidget(images, 1);
 	connect(images, SIGNAL(highlighted(const QString &)), SLOT(imageSelected(const QString &)));
 	QWhatsThis::add(images, _("This is the list of kernels and operating systems you can currently boot. Select which one you want to edit here."));
-	
+
 	parameters=new QVBox(this);
 	parameters->setMargin(SPACE_MARGIN);
 	parameters->setSpacing(SPACE_INSIDE);
 	layout->addWidget(parameters, 2);
 	image=new EditWidget(_("&Kernel:"), "", true, parameters);
 	QWhatsThis::add(image, _("Enter the filename of the kernel you want to boot here."));
+	connect(image, SIGNAL(textChanged(const QString &)), this, SIGNAL(configChanged()));
 	label=new EditWidget(_("&Label:"), "", false, parameters);
 	QWhatsThis::add(label, _("Enter the label (name) of the kernel you want to boot here."));
+	connect(label, SIGNAL(textChanged(const QString &)), this, SIGNAL(configChanged()));
 	root=new EditWidget(_("&Root filesystem:"), "", true, parameters);
 	QWhatsThis::add(root, _("Enter the root filesystem (i.e. the partition that will be mounted as / at boot time) for the kernel you want to boot here."));
+	connect(root, SIGNAL(textChanged(const QString &)), this, SIGNAL(configChanged()));
 	initrd=new EditWidget(_("&Initial ramdisk:"), "", true, parameters);
 	QWhatsThis::add(initrd, _("If you want to use an initial ramdisk (initrd) for this kernel, enter its filename here. Leave this field blank if you don't intend to use an initial ramdisk for this kernel."));
+	connect(initrd, SIGNAL(textChanged(const QString &)), this, SIGNAL(configChanged()));
 	append=new EditWidget(_("E&xtra parameters:"), "", false, parameters);
 	QWhatsThis::add(append, _("Enter any extra parameters you wish to pass to the kernel here. Usually, this can be left blank.<br>This sets the <i>append</i> option in lilo.conf."));
-	
+	connect(append, SIGNAL(textChanged(const QString &)), this, SIGNAL(configChanged()));
+
 	actions=new QVBox(this);
 	actions->setMargin(SPACE_MARGIN);
 	actions->setSpacing(SPACE_INSIDE);
@@ -55,10 +60,10 @@ Images::Images(liloconf *l, QWidget *parent, const char *name):QWidget(parent, n
 	check=new QPushButton(_("&Check Configuration"), actions);
 	connect(check, SIGNAL(clicked()), SLOT(checkClicked()));
 	QWhatsThis::add(check, _("Run LILO in test mode to see if the configuration is ok"));
-	addKrnl=new QPushButton(_("Add &Kernel"), actions);
+	addKrnl=new QPushButton(_("Add &Kernel..."), actions);
 	connect(addKrnl, SIGNAL(clicked()), SLOT(addKrnlClicked()));
 	QWhatsThis::add(addKrnl, _("Add a new Linux kernel to the boot menu"));
-	addOS=new QPushButton(_("Add Other &OS"), actions);
+	addOS=new QPushButton(_("Add Other &OS..."), actions);
 	connect(addOS, SIGNAL(clicked()), SLOT(addOSClicked()));
 	QWhatsThis::add(addOS, _("Add a non-Linux OS to the boot menu"));
 	remove=new QPushButton(_("&Remove Entry"), actions);
@@ -154,7 +159,7 @@ void Images::addKrnlClicked() // SLOT
 	InputBox::entry l0={ _("&Kernel filename:"), "", true, _("Enter the filename of the kernel you want to boot here.") };
 	InputBox::entry l1={ _("&Label:"), "", false, _("Enter the label (name) of the kernel you want to boot here.") };
 	InputBox::entry l2={ _("&Root filesystem:"), "", true, _("Enter the root filesystem (i.e. the partition that will be mounted as / at boot time) for the kernel you want to boot here.") };
-	InputBox::entry l3={ _("&Initial Ramdisk:"), "", true, _("If you want to use an initial ramdisk (initrd) for this kernel, enter its filename here. Leave this field blank if you don't intend to use an initial ramdisk for this kernel.") };
+	InputBox::entry l3={ _("&Initial ramdisk:"), "", true, _("If you want to use an initial ramdisk (initrd) for this kernel, enter its filename here. Leave this field blank if you don't intend to use an initial ramdisk for this kernel.") };
 	e.insert(e.end(), l0);
 	e.insert(e.end(), l1);
 	e.insert(e.end(), l2);
@@ -225,6 +230,8 @@ QString value(QString const &s)
 
 void Images::imageSelected(const QString &i) // SLOT
 {
+	bool blocked = signalsBlocked();
+	blockSignals(true);
 	QString s=i;
 	if(s.right(10)==" (default)")
 		s=s.left(s.length()-10);
@@ -265,6 +272,7 @@ void Images::imageSelected(const QString &i) // SLOT
 			append->hide();
 		}
 	}
+	blockSignals(blocked);
 }
 void Images::saveChanges() // SLOT
 {
@@ -279,3 +287,20 @@ void Images::saveChanges() // SLOT
 		}
 	}
 }
+
+void Images::makeReadOnly()
+{
+    images->setEnabled( false );
+    image->setEnabled( false );
+    label->setEnabled( false );
+    root->setEnabled( false );
+    initrd->setEnabled( false );
+    append->setEnabled( false );
+    dflt->setEnabled( false );
+    details->setEnabled( false );
+    probe->setEnabled( false );
+    check->setEnabled( false );
+    addKrnl->setEnabled( false );
+    addOS->setEnabled( false );
+    remove->setEnabled( false );
+}
