@@ -7,13 +7,13 @@
 #include "general.h"
 #include "images.h"
 #include "expert.h"
-#include "about.h"
 
 class MainWidget: public QTabWidget {
 	Q_OBJECT
 public:
 	MainWidget(QWidget *parent, const char *name=0);
 	void arrangeWidgets();
+    void makeReadOnly();
 public slots:
 	void load();
 	void save();
@@ -27,7 +27,6 @@ private:
 	General *general;
 	Images	*images;
 	Expert	*expert;
-	About	*about;
 	liloconf *l;
 };
 #endif
