@@ -3,6 +3,8 @@
 #include <kcmodule.h>
 #include "mainwidget.h"
 
+class KAboutData;
+
 class KControl: public KCModule {
 	Q_OBJECT
 public:
@@ -11,6 +13,7 @@ public:
 	void save();
 	void defaults();
 	void reset();
+	const KAboutData* aboutData() const;
 public slots:
 	void configChanged();
 private:
